@@ -14,6 +14,8 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, Poses):
             return obj.__dict__
+        elif isinstance(obj, ForceTorque):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -34,6 +36,8 @@ class JsonDecoder(json.JSONDecoder):
                 return Pose(**obj)
             if '_type' in obj and obj['_type'] == 'poses':
                 return Poses(**obj)
+            if '_type' in obj and obj['_type'] == 'force_torque':
+                return ForceTorque(**obj)
         return obj
 
 
